<?php

namespace Drupal\synimport\Drush;

use Drush\Commands\DrushCommands;
use Drupal\synimport\Service\Export\Export;
use Drupal\synimport\Service\Logger;
use Drupal\synimport\Utility\EmptyDirException;

/**
 * A Drush commandfile.
 */
class DrushContentExport extends DrushCommands {
  /**
   * Logger variable.
   *
   * @var Logger
   */
  protected $log;

  /**
   * Export Service variable.
   *
   * @var Export
   */
  protected $synexport;

  /**
   * Command constructor.
   *
   * @param Logger $log
   * @param Export $synexport
   */
  public function __construct(Logger $log, Export $synexport) {
    $this->log = $log;
    $this->synexport = $synexport;
  }

  /**
   * Synapse Content export.
   *
   * @param string $export_dir
   *   Directory for export.
   *
   * @param string $status
   *   Entities status to export. Default 1.
   *
   * @command synexport
   */
  public function export($export_dir, $status = '1') {
    $this->synexport->setLogger($this->log);
    $this->synexport->export($export_dir, $status);
  }

  /**
   * Synapse Taxonomy export.
   *
   * @param string $export_dir
   *   Directory for export.
   *
   * @param string $status
   *   Terms status to export. Default 1.
   *
   * @command synexport:taxonomy
   */
  public function exportTaxonomy($export_dir, $status = '1') {
    $this->synexport->setLogger($this->log);
    $this->synexport->exportTaxonomy($export_dir, 'taxonomy_term', $status);
  }

  /**
   * Synapse Nodes export.
   *
   * @param string $export_dir
   *   Directory for export.
   *
   * @param string $bundle
   *   Node bundle to export. Default 'node'.
   *
   * @param string $status
   *   Node status to export. Default 1.
   *
   * @command synexport:node
   */
  public function exportNode($export_dir, $bundle = 'node', $status = '1') {
    $this->synexport->setLogger($this->log);
    $this->synexport->exportNode($export_dir, $bundle, $status);
  }

  /**
   * Synapse Products export.
   *
   * @param string $export_dir
   *   Directory for export.
   *
   * @param string $bundle
   *   Product bundle to export. Default 'commerce_product'.
   *
   * @param string $status
   *   Product status to export. Default 1.
   *
   * @command synexport:product
   */
  public function exportProducts($export_dir, $bundle = 'commerce_product', $status = '1') {
    $this->synexport->setLogger($this->log);
    $this->synexport->exportProducts($export_dir, $bundle, $status);
  }

  /**
   * Synapse Blocks export.
   *
   * @param string $export_dir
   *   Directory for export.
   *
   * @param string $bundle
   *   Blocks bundle to export. Default 'block'.
   *
   * @param string $status
   *   Blocks status to export. Default 1.
   *
   * @command synexport:block
   */
  public function exportBlocks($export_dir, $bundle = 'block', $status = '1') {
    $this->synexport->setLogger($this->log);
    $this->synexport->exportBlocks($export_dir, $bundle, $status);
  }

}
